@@ -65,15 +65,15 @@ class CrudView(View):
         self.data = crud.get()
         return self._respond()
 
-    def post(self, request, **kwargs):
+    def post(self, request, filters, **kwargs):
         print('in post')
-        crud = self.CRUD_CLASS()
+        crud = self.CRUD_CLASS(filters)
         body = unjsonize(request.body.decode())
         self.data = crud.post(**body, **kwargs)
         return self._respond()
 
     def bulk_post(self, request, filters, **kwargs):
-        crud = self.CRUD_CLASS()
+        crud = self.CRUD_CLASS(filters)
         body = unjsonize(request.body.decode())
         self.data = crud.bulk_post(data=body, **filters, **kwargs)
         return self._respond()
